# XY

XY commands are used to plot X-Y data and store its display attributes and to write X-Y data to an ASCII file.

## Create XY Objects in Session

```{eval-rst}
.. autoclass:: abaqus.XY.XYSession.XYSession
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

## Other Classes

```{eval-rst}

.. toggle::

    .. autoclass:: abaqus.XY.XYSessionBase.XYSessionBase
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.XY.Area.Area
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.XY.AreaStyle.AreaStyle
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.XY.Axis.Axis
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.XY.AxisArray.AxisArray
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.XY.AxisData.AxisData
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.XY.Chart.Chart
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.XY.DefaultChartOptions.DefaultChartOptions
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.XY.DefaultPlot.DefaultPlot
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.XY.Legend.Legend
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.XY.LineStyle.LineStyle
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.XY.QuantityType.QuantityType
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.XY.SymbolStyle.SymbolStyle
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.XY.TextStyle.TextStyle
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.XY.Title.Title
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. automodule:: abaqus.XY.writeXYReport
        :members:
        :special-members: __init__
        :show-inheritance:

    .. autoclass:: abaqus.XY.XYCurve.XYCurve
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.XY.XYCurveArray.XYCurveArray
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.XY.XYData.XYData
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.XY.XYPlot.XYPlot
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::
    ```

    ```{eval-rst}
    .. autoclass:: abaqus.XY.XYPlotBase.XYPlotBase
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.XY.XYReportOptions.XYReportOptions
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::
```
